@@ -24,7 +24,7 @@ LearnerClustDiana = R6Class("LearnerClustDiana",
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
       param_set = ps(
-        metric = p_fct(default = "euclidean", levels = c("euclidean", "manhattan"), tags = "train"),
+        metric = p_fct(c("euclidean", "manhattan"), default = "euclidean", tags = "train"),
         stand = p_lgl(default = FALSE, tags = "train"),
         trace.lev = p_int(0L, default = 0L, tags = "train"),
         k = p_int(1L, default = 2L, tags = c("train", "predict"))
@@ -44,6 +44,7 @@ LearnerClustDiana = R6Class("LearnerClustDiana",
       )
     }
   ),
+
   private = list(
     .train = function(task) {
       pv = self$param_set$get_values(tags = "train")
