@@ -22,12 +22,15 @@ LearnerClustHDBSCAN = R6Class("LearnerClustHDBSCAN",
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
       param_set = ps(
-        minPts = p_int(0L, tags = c("required", "train")),
+        minPts = p_int(0L, tags = c("train", "required")),
+        cluster_selection_epsilon = p_dbl(default = 0, tags = "train"),
         gen_hdbscan_tree = p_lgl(default = FALSE, tags = "train"),
         gen_simplified_tree = p_lgl(default = FALSE, tags = "train"),
         verbose = p_lgl(default = FALSE, tags = "train")
       )
 
+      param_set$set_values(minPts = 5L)
+
       super$initialize(
         id = "clust.hdbscan",
         feature_types = c("logical", "integer", "numeric"),
@@ -40,6 +43,7 @@ LearnerClustHDBSCAN = R6Class("LearnerClustHDBSCAN",
       )
     }
   ),
+
   private = list(
     .train = function(task) {
       pv = self$param_set$get_values(tags = "train")
