@@ -2,14 +2,14 @@ test_that("Basic ops on usarrests task", {
   task = tsk("usarrests")
   expect_task(task)
   expect_task_clust(task)
-  expect_identical(task$target_names, character(0L))
+  expect_identical(task$target_names, character())
 })
 
 test_that("Basic ops on ruspini task", {
   task = tsk("ruspini")
   expect_task(task)
   expect_task_clust(task)
-  expect_identical(task$target_names, character(0L))
+  expect_identical(task$target_names, character())
 })
 
 test_that("0 feature task", {
