@@ -1,7 +1,7 @@
 skip_if_not_installed("e1071")
 
 test_that("autotest", {
-  learner = mlr3::lrn("clust.cmeans")
+  learner = lrn("clust.cmeans")
   expect_learner(learner)
   result = run_autotest(learner)
   expect_true(result, info = result$error)
@@ -33,13 +33,13 @@ test_that("Learner properties are respected", {
     p = learner$train(task)$predict(task)
     expect_prediction_clust(p)
 
-    if ("complete" %in% learner$properties) {
+    if ("complete" %chin% learner$properties) {
       expect_prediction_complete(p, learner$predict_type)
     }
-    if ("exclusive" %in% learner$properties) {
+    if ("exclusive" %chin% learner$properties) {
       expect_prediction_exclusive(p, learner$predict_type)
     }
-    if ("fuzzy" %in% learner$properties) {
+    if ("fuzzy" %chin% learner$properties) {
       expect_prediction_fuzzy(p)
     }
   }
