@@ -1,5 +1,5 @@
 test_that("autotest", {
-  learner = mlr3::lrn("clust.hclust")
+  learner = lrn("clust.hclust")
   expect_learner(learner)
   task = generate_tasks(learner)
   learner$train(task[[1]])
@@ -26,13 +26,13 @@ test_that("Learner properties are respected", {
     p = suppressWarnings(learner$train(task)$predict(task))
     expect_prediction_clust(p)
 
-    if ("complete" %in% learner$properties) {
+    if ("complete" %chin% learner$properties) {
       expect_prediction_complete(p, learner$predict_type)
     }
-    if ("exclusive" %in% learner$properties) {
+    if ("exclusive" %chin% learner$properties) {
       expect_prediction_exclusive(p, learner$predict_type)
     }
-    if ("fuzzy" %in% learner$properties) {
+    if ("fuzzy" %chin% learner$properties) {
       expect_prediction_fuzzy(p)
     }
   }
