@@ -1,7 +1,7 @@
 skip_if_not_installed("dbscan")
 
 test_that("autotest", {
-  learner = mlr3::lrn("clust.optics", eps = 25, eps_cl = 20)
+  learner = lrn("clust.optics", eps = 25, eps_cl = 20)
   expect_learner(learner)
   result = run_autotest(learner)
   expect_true(result, info = result$error)
@@ -26,10 +26,10 @@ test_that("Learner properties are respected", {
     p = learner$train(task)$predict(task)
     expect_prediction_clust(p)
 
-    if ("complete" %in% learner$properties) {
+    if ("complete" %chin% learner$properties) {
       expect_prediction_complete(p, learner$predict_type)
     }
-    if ("exclusive" %in% learner$properties) {
+    if ("exclusive" %chin% learner$properties) {
       expect_prediction_exclusive(p, learner$predict_type)
     }
   }
